**************************
The sherpa.astro.io module
**************************

.. currentmodule:: sherpa.astro.io

.. automodule:: sherpa.astro.io

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      set_io_backend
      TemporaryIOBackend
      IO_BACKENDS
      read_table
      read_image
      read_arf
      read_rmf
      read_arrays
      read_pha
      write_arf
      write_image
      write_pha
      write_rmf
      write_table
      pack_table
      pack_image
      pack_pha
      read_table_blocks
